@@ -40,7 +40,7 @@ global dateformat_view
    button $win.frm.ok -text OK -width 7 \
    		-command "logEdit_selOk $win $win.date.e $dateformat_view"
    button $win.frm.cancel -text [mc Cancel] -width 7 -command "destroy $win"
-   pack $win.frm.ok $win.frm.cancel -side left -fill x -expand 1
+   pack $win.frm.ok $win.frm.cancel -side left -fill x 
    pack $win.frm -side top -expand 1 -fill x
 }
 # ---------------------- logEdit_selOk ----------------------------------
@@ -694,7 +694,7 @@ proc logEdit_edShell {idx ipos} {
 	 		[clock format [clock seconds] -format %Y%m%d%H%M%S]
    }
    grid $win.body.lDescription -row $irow -column 0 -sticky e
-   pack $win.body.frm.vscr -side left -fill y
+   pack $win.body.frm.vscr -side left -fill y -expand 1
    grid $win.body.frm -row $irow -column 1 -sticky nsew
    pack $win.body -side top -fill both -expand 1
 
@@ -706,7 +706,7 @@ proc logEdit_edShell {idx ipos} {
    button $win.control.help -text [mc Help] -width 10 \
    	-command "taghelp $helpid"
    pack $win.control.ok $win.control.cancel $win.control.help \
-   				-side left -fill x -expand 1
+   				-side left -fill x 
    pack $win.control -side top
 }
 # ---------------------- logEdit_menu -----------------------------------
