@@ -121,20 +121,32 @@ global hh mm ss year month day
 global validStates projects
 global scrollside
 global allcontacts
+global currentProject
+
+set actin_filled_fields {}
+set actin_empty_fields {}
+
 
 proc actin_setup_field { window winnum mode label variable label_width var_width var_type help_id var_default args } {
 global $variable
 global scrollside
 global actin_f_a
 
+upvar actin_filled_fields filled_fields
+upvar actin_emtpy_fields empty_fields
+
 regsub -all {\.-} $label _ safe_label
 set safe_label [string tolower $safe_label]
 
 if { $mode == "input" } {
 set $variable "$var_default"
-}
+set filled 1
+} else {
+ set filled 0
+ }
+
 frame $window.m.c.f.$safe_label
-menubutton $window.m.c.f.$safe_label.tagname -text "$label" -width $label_width -menu $window.m.c.f.$safe_label.tagname.m
+menubutton $window.m.c.f.$safe_label.tagname -text [mc $label] -width $label_width -menu $window.m.c.f.$safe_label.tagname.m
 menu $window.m.c.f.$safe_label.tagname.m
 if { $var_type == "selection" } {
 
@@ -174,6 +186,12 @@ if { $mode == "edit" } {
 } else {
 pack $window.m.c.f.$safe_label.tagname $window.m.c.f.$safe_label.tagvalue -in $window.m.c.f.$safe_label -side left
 }
+
+if { $filled } {
+lappend filled_fields $window.m.c.f.$safe_label
+ } else {
+ lappend empty_fields $window.m.c.f.$safe_label
+}
 pack $window.m.c.f.$safe_label
 
 }
@@ -205,20 +223,22 @@ set f [frame $w.m.c.f -bd 0]
 $w.m.c create window 0 0 -anchor nw -window $f
 
 
-actin_setup_field $w $winnum $mode Id actin_f_a($winnum,Id) $lw 40 string actinput_id "*Auto*" 
+actin_setup_field $w $winnum $mode Id actin_f_a($winnum,Id) $lw 40 string actinput_id "*Auto*"
 
-actin_setup_field $w $winnum $mode [mc Title] actin_f_a($winnum,Title) $lw 40 string actinput_title ""
+actin_setup_field $w $winnum $mode Title actin_f_a($winnum,Title) $lw 40 string actinput_title ""
 
+# set the first active project to be the current project
+lappend activeproj $currentProject
 for { set i 0 } {$i < [llength $projects]} {incr i} {
  if { ! [projclosed [lindex [lindex $projects $i] 0]] } {
  lappend activeproj [lindex [lindex $projects $i] 0]
  }
 }
-actin_setup_field $w $winnum $mode [mc Project] actin_f_a($winnum,Project) $lw 40 selection actinput_project "" $activeproj $activeproj
+actin_setup_field $w $winnum $mode Project actin_f_a($winnum,Project) $lw 40 selection actinput_project "" $activeproj $activeproj
 
-actin_setup_field $w $winnum $mode [mc Date] actin_f_a($winnum,Date) $lw 40 string actinput_date "$year-$month-$day $hh:$mm"
+actin_setup_field $w $winnum $mode Date actin_f_a($winnum,Date) $lw 40 string actinput_date "$year-$month-$day $hh:$mm"
 
-actin_setup_field $w $winnum $mode [mc Priority] actin_f_a($winnum,Priority) $lw 40 selection actinput_priority 50 {10 20 30 40 50 60 70 80 90} {10 20 30 40 50 60 70 80 90}
+actin_setup_field $w $winnum $mode Priority actin_f_a($winnum,Priority) $lw 40 selection actinput_priority 50 {10 20 30 40 50 60 70 80 90} {10 20 30 40 50 60 70 80 90}
 
 #%%%%%%%%%% translate "valideStates %%%%%%%%%%%%%%%%
 # PROBLEM: the translation of the menu entries can be translated
@@ -229,25 +249,25 @@ foreach i $validStates {
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 actin_setup_field $w $winnum $mode Status actin_f_a($winnum,Status) $lw 40 selection actinput_status Pending $vStates $validStates
 
-actin_setup_field $w $winnum $mode [mc Expected-cost] actin_f_a($winnum,Expected-cost) $lw 40 string actinput_expected_cost ""
+actin_setup_field $w $winnum $mode Expected-cost actin_f_a($winnum,Expected-cost) $lw 40 string actinput_expected_cost ""
 
-actin_setup_field $w $winnum $mode [mc Expected-time] actin_f_a($winnum,Expected-time) $lw 40 selection actinput_expected_time "" [list "0:05" "0:10" "0:20" "0:30" "1:00" "2:00" "3:00" "4:00" "6:00" "8:00 (1 [mc day])" "12:00 (1.5 [mc days])" "16:00 (2 [mc days])" "24:00 (3 [mc days])" "40:00 (1 [mc week])"]  [list "0:05" "0:10" "0:20" "0:30" "1:00" "2:00" "3:00" "4:00" "6:00" "8:00" "12:00" "16:00" "24:00" "40:00"]
+actin_setup_field $w $winnum $mode Expected-time actin_f_a($winnum,Expected-time) $lw 40 selection actinput_expected_time "" [list "0:05" "0:10" "0:20" "0:30" "1:00" "2:00" "3:00" "4:00" "6:00" "8:00 (1 [mc day])" "12:00 (1.5 [mc days])" "16:00 (2 [mc days])" "24:00 (3 [mc days])" "40:00 (1 [mc week])"]  [list "0:05" "0:10" "0:20" "0:30" "1:00" "2:00" "3:00" "4:00" "6:00" "8:00" "12:00" "16:00" "24:00" "40:00"]
 
-actin_setup_field $w $winnum $mode [mc Expected-start-date] actin_f_a($winnum,Expected-start-date) $lw 38 date actinput_expected_start_date ""
+actin_setup_field $w $winnum $mode Expected-start-date actin_f_a($winnum,Expected-start-date) $lw 38 date actinput_expected_start_date ""
 
-actin_setup_field $w $winnum $mode [mc Expected-completed-date] actin_f_a($winnum,Expected-completed-date) $lw 38 date actinput_expected_completed_date ""
+actin_setup_field $w $winnum $mode Expected-completed-date actin_f_a($winnum,Expected-completed-date) $lw 38 date actinput_expected_completed_date ""
 
-actin_setup_field $w $winnum $mode [mc Precursor] actin_f_a($winnum,Precursor) $lw 40 string actinput_precursor ""
+actin_setup_field $w $winnum $mode Precursor actin_f_a($winnum,Precursor) $lw 40 string actinput_precursor ""
 
-actin_setup_field $w $winnum $mode [mc Active-after] actin_f_a($winnum,Active-after) $lw 40 string actinput_active_after ""
+actin_setup_field $w $winnum $mode Active-after actin_f_a($winnum,Active-after) $lw 38 date actinput_active_after ""
 
-actin_setup_field $w $winnum $mode [mc Subtask-of] actin_f_a($winnum,Subtask-of) $lw 40 string actinput_subtask_of ""
+actin_setup_field $w $winnum $mode Subtask-of actin_f_a($winnum,Subtask-of) $lw 40 string actinput_subtask_of ""
 
-actin_setup_field $w $winnum $mode [mc Next-action] actin_f_a($winnum,Next-action) $lw 40 actid_new actinput_next_action ""
+actin_setup_field $w $winnum $mode Next-action actin_f_a($winnum,Next-action) $lw 40 actid_new actinput_next_action ""
 
-actin_setup_field $w $winnum $mode [mc Abort-action] actin_f_a($winnum,Abort-action) $lw 40 actid_new actinput_abort_action ""
+actin_setup_field $w $winnum $mode Abort-action actin_f_a($winnum,Abort-action) $lw 40 actid_new actinput_abort_action ""
 
-actin_setup_field $w $winnum $mode [mc Difficulty] actin_f_a($winnum,Difficulty) $lw 40 selection actinput_difficulty "" [list "0 - [mc nobrainer]" "1 - [mc trivial]" "2 - [mc easy]" "3 - [mc tricky]" "4 - [mc hard]" "5 - [mc {very hard}]" ] { 0 1 2 3 4 5 }
+actin_setup_field $w $winnum $mode Difficulty actin_f_a($winnum,Difficulty) $lw 40 selection actinput_difficulty "" [list "0 - [mc nobrainer]" "1 - [mc trivial]" "2 - [mc easy]" "3 - [mc tricky]" "4 - [mc hard]" "5 - [mc {very hard}]" ] { 0 1 2 3 4 5 }
 
 
 foreach contact $allcontacts {
@@ -259,7 +279,7 @@ foreach contact $allcontacts {
   } elseif { [lindex $item 0] == "Email" } {
 	set thisemail [lindex $item 1]
   }
- } 
+ }
 if { ($thisid != "") && ($thisemail !="") } {
  lappend conids $thisid
  lappend conemails $thisemail
@@ -268,13 +288,22 @@ if { ($thisid != "") && ($thisemail !="") } {
 if { ! [info exists conids ] } { set conids "" }
 if { ! [info exists conemails ] } { set conemails "" }
 
-actin_setup_field $w $winnum $mode [mc Email-status-to] actin_f_a($winnum,Email-status-to) $lw 40 selection actinput_email_status_to "" $conids $conemails
 
-actin_setup_field $w $winnum $mode [mc Description] actin_f_a($winnum,Description) $lw 40 textarea actinput_description ""
+actin_setup_field $w $winnum $mode Email-status-to actin_f_a($winnum,Email-status-to) $lw 40 selection actinput_email_status_to "" $conids $conemails
 
-actin_setup_field $w $winnum $mode [mc Deliverable] actin_f_a($winnum,Deliverable) $lw 40 textarea actinput_deliverable ""
+actin_setup_field $w $winnum $mode Delegated-to actin_f_a($winnum,Delegated-to) $lw 40 selection actinput_delegated_to "" $conids $conids
 
-actin_setup_field $w $winnum $mode [mc Reason] actin_f_a($winnum,Reason) $lw 40 textarea actinput_reason ""
+actin_setup_field $w $winnum $mode Description actin_f_a($winnum,Description) $lw 40 textarea actinput_description ""
+
+actin_setup_field $w $winnum $mode Deliverable actin_f_a($winnum,Deliverable) $lw 40 textarea actinput_deliverable ""
+
+actin_setup_field $w $winnum $mode  Reason actin_f_a($winnum,Reason) $lw 40 textarea actinput_reason ""
+
+actin_setup_field $w $winnum $mode  Summary actin_f_a($winnum,Summary) $lw 40 textarea actinput_summary ""
+
+# Display the filled fields first
+# puts "filled fields are $actin_filled_fields"
+# puts "empty fields are $actin_empty_fields"
 
 set child [lindex [pack slaves $f] 0]
 
@@ -316,7 +345,7 @@ set thisaction ""
 set actin_f_a($winnum,Description) [string trim [$actin_win.m.c.f.description.tagvalue get 1.0 end]]
 set actin_f_a($winnum,Deliverable) [string trim [$actin_win.m.c.f.deliverable.tagvalue get 1.0 end]]
 set actin_f_a($winnum,Reason) [string trim [$actin_win.m.c.f.reason.tagvalue get 1.0 end]]
-
+set actin_f_a($winnum,Summary) [string trim [$actin_win.m.c.f.summary.tagvalue get 1.0 end]]
 
 set actmail_message [string trim [.actmail.message.body get 1.0 end]]
 
@@ -432,10 +461,12 @@ set action ""
  set action [tagappend $action Next-action $actin_f_a($winnum,Next-action)]
  set action [tagappend $action Abort-action $actin_f_a($winnum,Abort-action)]
  set action [tagappend $action Email-status-to $actin_f_a($winnum,Email-status-to)]
+ set action [tagappend $action Delegated-to $actin_f_a($winnum,Delegated-to)]
  set action [tagappend $action Difficulty $actin_f_a($winnum,Difficulty)]
  set action [tagappend $action Description $actin_f_a($winnum,Description) END_D]
  set action [tagappend $action Deliverable $actin_f_a($winnum,Deliverable) END_D]
  set action [tagappend $action Reason $actin_f_a($winnum,Reason) END_D]
+ set action [tagappend $action Summary $actin_f_a($winnum,Summary) END_D]
 
 if { $endflag } {
  set endpair [list End ]
@@ -522,7 +553,7 @@ tkwait window .avsa
 }
 
 proc set_actsel_tests {} {
-global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_completed actsel_st_aborted actsel_showfields actsel_maxpriority actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_filename actsel_id actsel_title
+global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_showfields actsel_maxpriority actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_filename actsel_id actsel_title
 
 if {$actsel_project !=""} {
  set test [list Project == $actsel_project]
@@ -538,9 +569,12 @@ if {! $actsel_st_any } {
  if { $actsel_st_active } {
 	lappend status_list Active
 	}
- if { $actsel_st_blocked } {
-	lappend status_list Blocked
+ if { $actsel_st_delegated } {
+	lappend status_list Delegated
 	}
+ if { $actsel_st_blocked } {
+       lappend status_list Blocked
+       }
  if { $actsel_st_completed } {
 	lappend status_list Completed
 	}
@@ -606,6 +640,7 @@ getallact
 set actin_f_a($winnum,Description) ""
 set actin_f_a($winnum,Reason) ""
 set actin_f_a($winnum,Deliverable) ""
+set actin_f_a($winnum,Summary) ""
 
 if { [info exist actedit_fields] } {
  unset actedit_fields
@@ -653,10 +688,14 @@ foreach action $thisaction {
    set actin_f_a($winnum,Description) [lindex $item 1]
  } elseif { [lindex $item 0] == "Deliverable"} {
    set actin_f_a($winnum,Deliverable) [lindex $item 1]
- } elseif { [lindex $item 0] == "Reason" } {
+   } elseif { [lindex $item 0] == "Reason" } {
    set actin_f_a($winnum,Reason)  [lindex $item 1]
+   } elseif { [lindex $item 0] == "Summary" } {
+   set actin_f_a($winnum,Summary)  [lindex $item 1]
  } elseif { [lindex $item 0] == "Email-status-to"} {
    set actin_f_a($winnum,Email-status-to) [lindex $item 1]
+ } elseif { [lindex $item 0] == "Delegated-to"} {
+   set actin_f_a($winnum,Delegated-to) [lindex $item 1]
  } elseif { [lindex $item 0] == "End" } {
    # special case - dont do anything
  } elseif { [lindex $item 0] == "Id" } {
@@ -682,14 +721,14 @@ if { $tagname == $selector } {
    .actview.main.body insert end "\n"
 }
 }
- 
+
 
 proc fillactwindow {} {
-global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_completed actsel_st_aborted actsel_showfields actsel_maxpriority actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_filename actsel_sortby
+global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_showfields actsel_maxpriority actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_filename actsel_sortby
 
 global actionsfilename allact
  .actview.main.body delete 1.0 end
- 
+
 .actview.main.body mark set prvmark 1.0
 .actview.main.body mark gravity prvmark left
 
@@ -759,16 +798,19 @@ foreach item $entry {
    }
    if { $actsel_showfields(project)} {
 	showactfield Project $tagname $tagvalue
-   } 
+   }
    if { $actsel_showfields(status)} {
 	showactfield Status $tagname $tagvalue
    }
    if { $actsel_showfields(expected_completed)} {
         showactfield Expected-completed-date $tagname $tagvalue
    }
+   if { $actsel_showfields(summary)} {
+   	showactfield Summary $tagname $tagvalue
+   }
   }
 
- } 
+ }
 
 
 }
@@ -851,7 +893,7 @@ global allact allactstate
 
 set redate $revisedExpectedDate($i)
 set retime $revisedExpectedTime($i)
-
+set summary [string trim [.acthist$i.summary.body get 1.0 end]]
 # The snag with only reading part of the actions file is that I will have to
 # now read the whole thing to update it.
 #set actions [tag readfile $actionsfilename]
@@ -865,6 +907,10 @@ if {$retime != ""} {
 tag setorreplace action Revised-expected-time $retime
 set revised 1
 }
+if {$summary !=""} {
+ tag setorreplace action Summary $summary
+ set revised 1
+}
 
 if {$revised} {
 tag setorreplace action Revised-date [clock format [clock seconds] -format "%Y-%m-%d"]
@@ -882,7 +928,7 @@ set test [ list Id "==" $thisid ]
 set idx 0
 foreach entry $allact {
  if [ tag matchcond $entry $test ] {
-    set allact [lreplace $allact $idx $idx $action] 
+    set allact [lreplace $allact $idx $idx $action]
  }
  incr idx
 }
@@ -904,7 +950,7 @@ toplevel .acthist$i
 wm title .acthist$i "[mc {Action history}] $i"
 
 frame .acthist$i.act
-text .acthist$i.act.body -rel sunk -wrap word -yscrollcommand ".acthist$i.act.sb set" -height 10
+text .acthist$i.act.body -rel sunk -wrap word -yscrollcommand ".acthist$i.act.sb set" -height 5
 scrollbar .acthist$i.act.sb -rel sunk -command ".acthist$i.act.body yview"
 pack .acthist$i.act.body -in .acthist$i.act -side right
 pack .acthist$i.act.sb -in .acthist$i.act -side right -fill y
@@ -917,6 +963,12 @@ pack .acthist$i.text.body -in .acthist$i.text -side right
 pack .acthist$i.text.sb -in .acthist$i.text -side right -fill y
 pack .acthist$i.text
 
+frame .acthist$i.summary
+text .acthist$i.summary.body -rel sunk -wrap word -yscrollcommand ".acthist$i.summary.sb set" -height 5
+scrollbar .acthist$i.summary.sb -rel sunk -command ".acthist$i.summary.body yview"
+pack .acthist$i.summary.body -in .acthist$i.summary -side right
+pack .acthist$i.summary.sb -in .acthist$i.summary -side right -fill y
+pack .acthist$i.summary
 
 frame .acthist$i.bot
 button .acthist$i.bot.revise -text [mc "Revise"] -command "doRevise \"$action\" $i"
@@ -934,7 +986,7 @@ pack .acthist$i.bot
 
 foreach item $action {
   set tagname [lindex $item 0]
-  set tagvalue [lindex $item 1] 
+  set tagvalue [lindex $item 1]
   if { $tagname == "Date" } {
     set actiondate $tagvalue
    } elseif { $tagname == "Title" } {
@@ -955,6 +1007,8 @@ foreach item $action {
     set actionrevisedexpectedtime $tagvalue
   } elseif { $tagname == "Revised-date" } {
     set actionreviseddate $tagvalue
+  } elseif { $tagname == "Summary" } {
+    set actionsummary $tagvalue
   }
 }
 
@@ -1039,6 +1093,10 @@ if [info exist actiontotal] {
 .acthist$i.act.body insert end "[mc {Total duration}]: $actiontotal\n"
 }
 
+.acthist$i.summary.body delete 1.0 end
+if [info exist actionsummary ] {
+.acthist$i.summary.body insert end "$actionsummary"
+}
 
 }
 
@@ -1055,7 +1113,7 @@ incr i
 }
 
 }
- 
+
 proc setup_actsel_menus {} {
 global actsel_filename actionsfilename allact
 
@@ -1091,7 +1149,7 @@ foreach item $action {
 
 proc actSelect { okcommand } {
 global projects
-global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_completed actsel_st_aborted actsel_maxpriority actsel_showfields actsel_filename actsel_filenames actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_id actsel_title actsel_projstat actsel_sortby
+global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_delegated actsel_st_completed actsel_st_aborted actsel_maxpriority actsel_showfields actsel_filename actsel_filenames actsel_expected_start actsel_expected_completed actsel_expected_start_test actsel_expected_completed_test actsel_id actsel_title actsel_projstat actsel_sortby
 
 proc setupActselProjMenu { varname index op } {
 global actsel_projstat
@@ -1143,9 +1201,10 @@ checkbutton .actsel.tagselect.status.unclaimed -text [mc Unclaimed] -variable ac
 checkbutton .actsel.tagselect.status.pending -text [mc Pending] -variable actsel_st_pending
 checkbutton .actsel.tagselect.status.active -text [mc Active] -variable actsel_st_active
 checkbutton .actsel.tagselect.status.blocked -text [mc Blocked] -variable actsel_st_blocked
+checkbutton .actsel.tagselect.status.delegated -text [mc Delegated] -variable actsel_st_delegated
 checkbutton .actsel.tagselect.status.completed -text [mc Completed] -variable actsel_st_completed
 checkbutton .actsel.tagselect.status.aborted -text [mc Aborted] -variable actsel_st_aborted
-pack .actsel.tagselect.status.l .actsel.tagselect.status.any .actsel.tagselect.status.unclaimed .actsel.tagselect.status.pending .actsel.tagselect.status.active .actsel.tagselect.status.blocked .actsel.tagselect.status.completed .actsel.tagselect.status.aborted -side left -in .actsel.tagselect.status
+pack .actsel.tagselect.status.l .actsel.tagselect.status.any .actsel.tagselect.status.unclaimed .actsel.tagselect.status.pending .actsel.tagselect.status.active .actsel.tagselect.status.blocked .actsel.tagselect.status.delegated .actsel.tagselect.status.completed .actsel.tagselect.status.aborted -side left -in .actsel.tagselect.status
 pack .actsel.tagselect.status
 
 frame .actsel.tagselect.priority
@@ -1209,8 +1268,9 @@ checkbutton .actsel.fields.priority -text [mc Priority] -variable actsel_showfie
 checkbutton .actsel.fields.project -text [mc Project] -variable actsel_showfields(project)
 checkbutton .actsel.fields.status -text Status -variable actsel_showfields(status)
 checkbutton .actsel.fields.completeddate -text [mc "Due Date"] -variable actsel_showfields(expected_completed)
+checkbutton .actsel.fields.summary -text [mc Summary] -variable actsel_showfields(summary)
 
-pack .actsel.fields.l .actsel.fields.all .actsel.fields.id .actsel.fields.date .actsel.fields.title .actsel.fields.priority .actsel.fields.project .actsel.fields.status .actsel.fields.completeddate -in .actsel.fields -side left
+pack .actsel.fields.l .actsel.fields.all .actsel.fields.id .actsel.fields.date .actsel.fields.title .actsel.fields.priority .actsel.fields.project .actsel.fields.status .actsel.fields.completeddate .actsel.fields.summary -in .actsel.fields -side left
 pack .actsel.fields
 
 frame .actsel.oneact
@@ -1689,3 +1749,67 @@ donext ""
 actNewState $a Aborted Active "" ""
 getactiveactions
 }
+
+proc archiveOldActions {} {
+#
+# Move all actions completed or aborted more than a month ago to an archive
+# file
+global allact allactstate
+
+proc oldActionsArchiveName { archdate } {
+global rootdir
+# return the name of the old actions file - takes in a date which is
+# the nomimal archive date..
+
+set yearmon [clock format [clock scan $archdate] -format "%Y%m"]
+
+return "$rootdir/actions-$yearmon.tag"
+
+
+}
+
+set monthdate [clock format [clock scan "last month"] -format "%Y-%m-01"]
+
+getallact
+
+# extract the actions which are completed or aborted before the date
+
+set headerwritten 0
+
+set test [list Completed-date "-earlier" $monthdate]
+lappend tdates $test
+set test [list Aborted-date "-earlier" $monthdate]
+lappend tdates $test
+
+
+foreach entry $allact {
+
+if { [tag matchany $entry $tdates] } {
+
+if { ! $headerwritten } {
+  set filename [oldActionsArchiveName $monthdate]
+  if { ! [ file exists $filename] } { 
+  set f [open $filename w]
+  puts $f "Tag-action-version: 1.0"
+  puts $f "End:"
+  } else {
+   set f [open $filename a]
+  }
+  set headerwritten 1
+  }
+  tag writeentry $f $entry
+  } else {
+  lappend newacts $entry
+}
+
+
+}
+if { $headerwritten } {
+ close $f
+}
+# Now - we update allact to be newacts
+# puts "newacts is $newacts"
+set allact $newacts
+set allactstate modified
+writeallact
+}
