@@ -1,13 +1,15 @@
 #
 # taglog_init.tcl - initialisation routines for taglog
-# Copyright John Lines (john@paladin.demon.co.uk) July 2000
+# Copyright John Lines (john@paladin.demon.co.uk) July 2000, January 2003
 #
 # This program is released under the terms of the GNU Public Licence
 #
 
 package provide taglog_init 0.1
 
+
 proc initialise {} {
+global tcl_platform env
 global hh mm ss year month day currentStart currentEnd currentProject currentActivity logfilename \
  actionsfilename state projects projectsfilename activities rootdir currentAction
 global currentContact
@@ -22,6 +24,7 @@ global validStates
 global libsdir prefsfile display_prevday
 global actsel_project actsel_st_any actsel_st_unclaimed actsel_st_pending actsel_st_active actsel_st_blocked actsel_st_completed actsel_st_aborted actsel_filename actsel_filenames actsel_projstat actsel_sortby
 global showtime_format showtime_spreadoverheads showtime_bookbycode showtime_hours_per_day
+global timebook_startlastweek
 global actsel_maxpriority actsel_showfields
 global docdir
 global helpdir
@@ -30,7 +33,7 @@ global allactstate
 global language
 global allcontactsstate
 global rate
-global dateformat_view
+global dateformat_view dateformat_tcl
 global num_today_actions history_win_depth current_win_depth
 global html_public_dir html_private_dir
 global lvsa_dirname
@@ -39,6 +42,12 @@ global action_textarea_fields
 global GL_tableFont
 global GL_autoComCase
 global GL_autoComMsec
+global argv
+global start_procs exit_procs
+global stackdepth stack_info
+global projects_url
+global log_summary
+global activitiesfilename
 # Initialise common variables
 
 
@@ -64,7 +73,7 @@ set logentries {}
 set projTimes(unknown) "00:00"
 set projTimesTotal "00:00"
 set projTimesTotalNonBreaks "00:00"
-set validStates { Unclaimed Pending Active Blocked Completed Aborted }
+set validStates { Unclaimed Pending Active Blocked Delegated Completed Aborted }
 set prefsfile ""
 set actsel_st_any 1
 set actsel_st_unclaimed 1
@@ -80,8 +89,12 @@ set actsel_showfields(title) 1
 set actsel_showfields(priority) 0
 set actsel_showfields(project) 1
 set actsel_showfields(status) 1
+set actsel_showfields(summary) 1
 set actsel_projstat all
 set actsel_sortby ""
+set stackdepth 0
+set stack_info ""
+set log_summary ""
 # parameters for auto completion of entry widgets
 # case ignore case? 0=no, 1=yes
 set GL_autoComCase 1
@@ -94,32 +107,52 @@ set allcontactsstate closed
 set id_prefix ""
 set GL_tableFont "-*-courier-medium-r-normal--*-120-*"
 
-set action_textarea_fields { Description Deliverable Reason }
+set action_textarea_fields { Description Deliverable Reason Summary}
 
 # The following items are likely to be customised by the user
 
 set dateformat_view "YYYY-MM-DD"
+set dateformat_tcl "%Y-%m-%d"
+
 set rootdir "~/diary"
-set actionsfilename "$rootdir/actions.tag"
-set projectsfilename "$rootdir/projects.tag"
-set html_public_dir "~/public_html"
-set html_private_dir "~/diary/html"
-set lvsa_dirname ""
+if { $tcl_platform(platform) == "windows" } {
+ if [ info exists env(USERPROFILE)] {
+ set df [file join $env(USERPROFILE) diary]
+ if { [file isdirectory $env(USERPROFILE)] } {
+      set rootdir $df
+       }
+ }
+ }
+
+
+set start_procs {}
+set exit_procs {}
+
+set projects_url ""
+
+# delay setting the following until after the preferences file has been read
+ set actionsfilename ""
+ set projectsfilename ""
+ set html_public_dir ""
+ set html_private_dir ""
+ set lvsa_dirname ""
+ set activitiesfilename ""   
+ set contactsfilename ""
 
-set contactsfilename "$rootdir/contacts.tag"
 set contacttypes { colleague customer supplier contact friend }
 
 set projects {}
-#
-
 set rate ""
 
 set activities { phone-in phone-out meeting meeting-preparation meeting-review email reading programming writing thinking service-break informal-discussion }
 
+
 set showtime_format 1
-set showtime_spreadoverheads 0
+set showtime_spreadoverheads 1
 set showtime_bookbycode 0
 set showtime_hours_per_day 7.58
+set timebook_startlastweek 1
+
 
 # which side the scroll bars are, in windows with scroll bars
 set scrollside left
@@ -145,10 +178,12 @@ set scriptdir [file dirname [info script]]
 set helpdir $scriptdir
 if { [ file readable $scriptdir/taglog_help_en.tag] } {
   set helpdir $scriptdir
-  } elseif { [file readable ~/lib//taglog/taglog_help_en.tag] } {
-  set helpdir ~/lib
+  } elseif { [file readable ~/lib/taglog/taglog_help_en.tag] } {
+  set helpdir ~/lib/taglog
   } elseif { [file readable /usr/lib/taglog/taglog_help_en.tag] } {
   set helpdir /usr/lib/taglog
+  } elseif { [file readable /usr/share/taglog/taglog_help_en.tag] } {
+  set helpdir /usr/share/taglog
   } elseif {  [ file readable /usr/share/doc/taglog/taglog_help_en.tag] } {
   set helpdir /usr/share/doc/taglog
   } elseif { [ file readable /usr/local/doc/taglog_help_en.tag] } {
@@ -161,7 +196,24 @@ if { [ file readable $scriptdir/taglog_help_en.tag] } {
 
 set language en
 
-set dateformat_view "YYYY-MM-DD"
+
+if { [llength $argv] >0} {
+
+while {[string match -* [lindex $argv 0]]} {
+   switch -exact -- [lindex $argv 0] {
+     -c {
+      set prefsfile [lindex $argv 1]
+      set argv {}
+      
+	}
+
+
+  }
+  }
+
+
+}
+
 
 # Having set the defaults we will source /etc/taglog.conf if it exists
 
@@ -169,15 +221,40 @@ if {[file readable "/etc/taglog.conf"] } {
 	source /etc/taglog.conf
 	}
 
+
+if { $prefsfile == "" } {
+
+# This is for Unix
 if {[file readable "~/.taglog"] } {
 	source "~/.taglog"
 	set prefsfile "~/.taglog"
 	}
+# If c:\Documents and Settings\username\taglog.cfg exists then use that.
+if { $tcl_platform(platform) == "windows" } {
+ if [ info exists env(USERPROFILE)] {
+ set tf [file join $env(USERPROFILE) taglog.cfg]
+ if { [file readable $tf] } {
+       source $tf
+       set prefsfile $tf
+       }
+ }
+}
+
+# This is a Windows fallback
 if { [file readable "~/taglog.cfg"] } {
 	source "~/taglog.cfg"
 	set prefsfile "~/taglog.cfg"
 	}
 
+} else {
+ # prefs must have been set from command line
+ if { [file readable $prefsfile] } {
+    source $prefsfile
+    }
+
+}
+
+
 # If the preferences were not found then we should initialise then
 
 if { $prefsfile == "" } {
@@ -186,45 +263,139 @@ if { $prefsfile == "" } {
 # The following are automatically set, but depend on things from the user
 # preferences
 
+if { $actionsfilename == "" } { set actionsfilename "$rootdir/actions.tag" }
+if { $projectsfilename == "" } { set projectsfilename "$rootdir/projects.tag" }
+if { $html_public_dir == "" } { set html_public_dir "~/public_html" }
+if { $html_private_dir == "" } { set html_private_dir "$rootdir/html" }
+if { $contactsfilename == "" } { set contactsfilename "$rootdir/contacts.tag" }
+if { $activitiesfilename == ""} { set activitiesfilename "$rootdir/activities" }
+
 lappend actsel_filenames $actionsfilename
 lappend actsel_filenames "$docdir/taglog_todo.tag"
 set actsel_filename $actionsfilename
 
+if { $dateformat_view=="DD/MM/YYYY" } {
+ set dateformat_tcl "%d/%m/%Y" 
+  } elseif { $dateformat_view=="MM/DD/YYYY" } {
+ set dateformat_tcl "%m/%d/%Y"
+ } else { set dateformat_tcl "%Y-%m-%d" }
 
 # Post initialisation procedures
 FindDefaultPrevday
 
+#fill up the activities list from file
+#
+if {[file readable $activitiesfilename] } {
+set fileid [open $activitiesfilename  r+]
+seek $fileid 0 start
+set buffer [read $fileid];
+close $fileid
+set activities [split $buffer "\n"];
+}
+
+
 # read the projects file
 readprojects
 }
 
 proc initprefs {} {
+global tcl_platform rootdir env prefsfile
 # initialise the preferences file
-# does not do anything yet.
+# We should be able to just display the prefs dialog to let the user confirm
+
+# Since we are in the first time we dont really know what the users language
+# should be - default to the minimal mc so it exists when we call editPrefs
+
+ proc mc { msg } {
+   return $msg
+    }
+
+ wm iconify .
+
+ if {$tcl_platform(platform) == "unix"} {
+ set prefsfile "~/.taglog"
+ } 
+ if { $tcl_platform(platform) == "windows" } {
+ if [ info exists env(USERPROFILE)] {
+ set tf [file join $env(USERPROFILE) taglog.cfg]
+ if { [file isdirectory $env(USERPROFILE)] } {
+       set prefsfile $tf
+       }
+ }
+ if { $prefsfile == "" } { set prefsfile "~/taglog.cfg"}
+ }
+
+# Create a blank preferences file
+set header "# Preferences for taglog"
+set marker "# above this line is automatically saved - put your changes below here"
+set f [open $prefsfile w]
+ puts $f "$header"
+ puts $f "$marker"
+ close $f
+
+ editPrefs
+
+ wm deiconify .
 
 }
 
 proc editprefsOK {} {
 global docdir language editprefs_docdir editprefs_language
 global editprefs_showtime_hours_per_day showtime_hours_per_day
+global editprefs_showtime_spreadoverheads showtime_overheads
+global editprefs_timebook_startlastweek timebook_startlastweek
 global smtpv editprefs_smtp_thishost editprefs_smtp_mailhost editprefs_smtp_myemail editprefs_smtp_port editprefs_smtp_prefsfile
 global editprefs_dateformat dateformat_view dateformat_tcl
-global edtiprefs_rootdir rootdir
+global editprefs_rootdir rootdir
 global editprefs_history_win_depth editprefs_current_win_depth editprefs_num_today_actions
 global history_win_depth current_win_depth num_today_actions
 global id_prefix editprefs_id_prefix
 global helpdir editprefs_helpdir
+global start_procs editprefs_start_procs exit_procs editprefs_exit_procs
+global projects_url editprefs_projects_url
+global editprefs_activitiesFile
+global activities
+global activitiesfilename
 
-
+set activitiesfilename $editprefs_activitiesFile
 set docdir $editprefs_docdir
+set rootdir $editprefs_rootdir
 # set helpdir $editprefs_helpdir
 set language $editprefs_language
-set showtime_hours_per_day $editprefs_showtime_hours_per_day
+if { ( $showtime_hours_per_day < 24 ) && ( $editprefs_showtime_hours_per_day > 0) } {
+ set showtime_hours_per_day $editprefs_showtime_hours_per_day
+}
+set showtime_spreadoverheads $editprefs_showtime_spreadoverheads
+set timebook_startlastweek $editprefs_timebook_startlastweek
 set dateformat_view $editprefs_dateformat
-set history_win_depth $editprefs_history_win_depth
+if { $dateformat_view=="DD/MM/YYYY" } {
+ set dateformat_tcl "%d/%m/%Y"
+ }  elseif { $dateformat_view=="MM/DD/YYYY" } {
+  set dateformat_tcl "%m/%d/%Y" 
+ } else { set dateformat_tcl "%Y-%m-%d" }
+if { ($history_win_depth > 1) && ( $history_win_depth <80) } {
+ set history_win_depth $editprefs_history_win_depth
+}
+if { ($current_win_depth >1) && ( $current_win_depth <80) } {
 set current_win_depth $editprefs_current_win_depth
-set num_today_actions $editprefs_num_today_actions
+}
+if { ($editprefs_num_today_actions >=0) && ($editprefs_num_today_actions <21) } {
+ set num_today_actions $editprefs_num_today_actions
+}
 set id_prefix $editprefs_id_prefix
+set start_procs [split [string trim $editprefs_start_procs]]
+set projects_url $editprefs_projects_url
+if {  [can_get_httprojects] } {
+ catch {.mBar.projects.m entryconfigure 3 -state normal}
+}
+
+#fill up the activity list
+
+set fileid [open $activitiesfilename  r+]
+seek $fileid 0 start
+set buffer [read $fileid];
+close $fileid
+set activities [split $buffer "\n"];
 
 savePrefs
 
@@ -247,19 +418,26 @@ destroy .editprefs
 }
 
 
+
 proc editPrefs {} {
+global tcl_platform env
 global docdir language editprefs_docdir editprefs_language
 global rootdir editprefs_rootdir
 global editprefs_showtime_hours_per_day showtime_hours_per_day
+global editprefs_showtime_spreadoverheads showtime_spreadoverheads
+global editprefs_timebook_startlastweek timebook_startlastweek
 global smtpv editprefs_smtp_thishost editprefs_smtp_mailhost editprefs_smtp_myemail editprefs_smtp_port editprefs_smtp_prefsfile
 global editprefs_dateformat dateformat_view dateformat_tcl
-global edtiprefs_rootdir rootdir
+global editprefs_rootdir rootdir
 global prefsfile
 global editprefs_history_win_depth editprefs_current_win_depth editprefs_num_today_actions
 global history_win_depth current_win_depth num_today_actions
 global id_prefix editprefs_id_prefix
 global helpdir editprefs_helpdir
-
+global start_procs editprefs_start_procs exit_procs editprefs_exit_procs
+global projects_url editprefs_projects_url
+global activitiesfilename
+global editprefs_activitiesFile
 
 set realprefs [file nativename $prefsfile]
 
@@ -280,14 +458,58 @@ set editprefs_rootdir $rootdir
 frame .editprefs.rootdir
 menubutton .editprefs.rootdir.l -text [mc "Data directory root"] -menu .editprefs.rootdir.l.m
 menu .editprefs.rootdir.l.m
+if { $tcl_platform(platform) == "windows" } {
+ if [ info exists env(USERPROFILE)] {
+ set df [file join $env(USERPROFILE) diary]
+ if { [file isdirectory $env(USERPROFILE)] } {
+       .editprefs.rootdir.l.m add command -label $df -command "set editprefs_rootdir \"$df\""
+       }
+ }
+ }
 .editprefs.rootdir.l.m add command -label "~/diary" -command "set editprefs_rootdir \"~/diary\""
 .editprefs.rootdir.l.m add command -label "~/.taglog-diary" -command "set editprefs_rootdir \"~/.taglog-diary\""
 .editprefs.rootdir.l.m add separator
 .editprefs.rootdir.l.m add command -label [mc "Help"] -command "taghelp prefs_rootdir"
-entry .editprefs.rootdir.v -textvariable  editprefs_rootdir -width 30
+entry .editprefs.rootdir.v -textvariable  editprefs_rootdir -width 40
+
+if { [info tclversion] >= 8.3 } {
+
+button .editprefs.rootdir.pick -text [mc "Pick"] -command { set editprefs_rootdir [tk_chooseDirectory -title [mc "Data directory root"] -mustexist 0 -initialdir $editprefs_rootdir -parent .editprefs] }
+  }
 pack .editprefs.rootdir.l .editprefs.rootdir.v -side left -in .editprefs.rootdir
+if { [info tclversion] >= 8.3 } { pack .editprefs.rootdir.pick -side left -in .editprefs.rootdir }
 pack .editprefs.rootdir
 
+# Activities file
+
+set editprefs_activitiesFile "$activitiesfilename"
+frame .editprefs.activitiesFile
+menubutton .editprefs.activitiesFile.l -text [mc "Activities File"] -menu .editprefs.activitiesFile.l.m
+menu .editprefs.activitiesFile.l.m
+if { $tcl_platform(platform) == "windows" } {
+    if [ info exists env(USERPROFILE)] {
+	set df [file join $env(USERPROFILE) diary]
+	if { [file isdirectory $env(USERPROFILE)] } {
+	    .editprefs.activitiesFile.l.m add command -label $df -command "set editprefs_activitiesFile \"$df\""
+	}
+    }
+}
+.editprefs.activitiesFile.l.m add command -label "~/diary/activities" -command "set editprefs_activitiesFile \"~/diary/activities\""
+.editprefs.activitiesFile.l.m add command -label "~/.taglog_actvities" -command "set editprefs_activitiesFile \"~/.taglog_activities\""
+.editprefs.activitiesFile.l.m add separator
+.editprefs.activitiesFile.l.m add command -label [mc "Help"] -command "taghelp prefs_activitiesfile"
+entry .editprefs.activitiesFile.v -textvariable  editprefs_activitiesFile -width 40
+
+if { [info tclversion] >= 8.3 } {
+    
+    button .editprefs.activitiesFile.pick -text [mc "Pick"] -command { set editprefs_activitiesFile [tk_getOpenFile -title [mc "Activities File"]  -initialdir $editprefs_rootdir -parent .editprefs] }
+}
+
+
+pack .editprefs.activitiesFile.l .editprefs.activitiesFile.v -side left -in .editprefs.activitiesFile
+if { [info tclversion] >= 8.3 } { pack .editprefs.activitiesFile.pick -side left -in .editprefs.activitiesFile }
+pack .editprefs.activitiesFile
+
 
 # Language
 set editprefs_language $language
@@ -302,6 +524,25 @@ entry .editprefs.language.v -textvariable editprefs_language
 pack .editprefs.language.l .editprefs.language.v -side left -in .editprefs.language
 pack .editprefs.language
 
+set editprefs_showtime_spreadoverheads $showtime_spreadoverheads
+frame .editprefs.spreadoverheads
+menubutton .editprefs.spreadoverheads.l -text [mc "Spread Overheads"] -menu .editprefs.spreadoverheads.l.m
+menu .editprefs.spreadoverheads.l.m
+.editprefs.spreadoverheads.l.m add command -label [mc Help] -command "taghelp prefs_showtime_spreadoverheads"
+checkbutton .editprefs.spreadoverheads.e -relief flat -variable showtime_spreadoverheads
+# Put the Default time bookings report starts last week flag here too
+set editprefs_timebook_startlastweek $timebook_startlastweek
+menubutton .editprefs.spreadoverheads.l2 -text [mc "Time Bookings starts"] -menu .editprefs.spreadoverheads.l2.m
+menu .editprefs.spreadoverheads.l2.m
+.editprefs.spreadoverheads.l2.m add command -label [mc Help] -command "taghelp prefs_timebook_startlastweek"
+radiobutton .editprefs.spreadoverheads.r1 -text [mc "last week"] -variable editprefs_timebook_startlastweek -value 1
+radiobutton .editprefs.spreadoverheads.r2 -text [mc "this week"] -variable editprefs_timebook_startlastweek -value 0
+
+pack .editprefs.spreadoverheads.l .editprefs.spreadoverheads.e .editprefs.spreadoverheads.l2 .editprefs.spreadoverheads.r1 .editprefs.spreadoverheads.l2 .editprefs.spreadoverheads.r1 .editprefs.spreadoverheads.r2 -in .editprefs.spreadoverheads -side left
+pack .editprefs.spreadoverheads
+
+
+
 set editprefs_showtime_hours_per_day $showtime_hours_per_day
 frame .editprefs.hours
 menubutton .editprefs.hours.l -text [mc "Hours Worked per Day (decimal)"] -menu .editprefs.hours.l.m
@@ -346,6 +587,11 @@ set editprefs_num_today_actions $num_today_actions
 frame .editprefs.num_today_actions
 menubutton .editprefs.num_today_actions.l -text [mc "Number of 'Today' actions"] -menu .editprefs.num_today_actions.l.m
 menu .editprefs.num_today_actions.l.m
+.editprefs.num_today_actions.l.m add command -label "0" -command "set editprefs_num_today_actions 0"
+.editprefs.num_today_actions.l.m add command -label "1" -command "set editprefs_num_today_actions 1"
+.editprefs.num_today_actions.l.m add command -label "2" -command "set editprefs_num_today_actions 2"
+.editprefs.num_today_actions.l.m add command -label "3" -command "set editprefs_num_today_actions 3"
+.editprefs.num_today_actions.l.m add separator
 .editprefs.num_today_actions.l.m add command -label [mc "Help"] -command "taghelp editprefs_num_today_actions"
 entry .editprefs.num_today_actions.e -textvariable editprefs_num_today_actions
 pack .editprefs.num_today_actions.l .editprefs.num_today_actions.e -side left -in .editprefs.num_today_actions
@@ -360,6 +606,26 @@ entry .editprefs.id_prefix.e -textvariable editprefs_id_prefix
 pack .editprefs.id_prefix.l .editprefs.id_prefix.e -side left -in .editprefs.id_prefix
 pack .editprefs.id_prefix
 
+set editprefs_start_procs $start_procs
+frame .editprefs.start_procs
+menubutton .editprefs.start_procs.l -text [mc "Start Procs"] -menu .editprefs.start_procs.l.m
+menu .editprefs.start_procs.l.m
+.editprefs.start_procs.l.m add command -label "--" -command "set editprefs_start_procs \"\""
+.editprefs.start_procs.l.m add command -label "iconify_mainwin doShowProjects" -command "set editprefs_start_procs \"iconify_mainwin doShowProjects\""
+.editprefs.start_procs.l.m add separator
+.editprefs.start_procs.l.m add command -label [mc "Help"] -command "taghelp editprefs_start_procs"
+entry .editprefs.start_procs.e -textvariable editprefs_start_procs
+pack .editprefs.start_procs.l .editprefs.start_procs.e -side left -in .editprefs.start_procs
+pack .editprefs.start_procs
+
+set editprefs_projects_url $projects_url
+frame .editprefs.projects_url
+menubutton .editprefs.projects_url.l -text [mc "Projects URL"] -menu .editprefs.projects_url.l.m
+menu .editprefs.projects_url.l.m
+.editprefs.projects_url.l.m add command -label [mc "Help"] -command "taghelp editprefs_projects_url"
+entry .editprefs.projects_url.e -textvariable editprefs_projects_url -width 40
+pack .editprefs.projects_url.l .editprefs.projects_url.e -side left -in .editprefs.projects_url
+pack .editprefs.projects_url
 
 smtp init
 
@@ -433,13 +699,21 @@ global projects
 global docdir
 global language
 global showtime_hours_per_day
-global dateformat_view
+global dateformat_view dateformat_tcl
 global rootdir
 global num_today_actions history_win_depth current_win_depth
 global id_prefix
+global start_procs exit_procs
+global projects_url
+global showtime_spreadoverheads
+global timebook_startlastweek
+global activities
+global activitiesfilename
+
+
 
 set header "# Preferences for taglog"
-set marker "# above this line is automatically saved - put your changes below here"
+set marker "# above this line is automatically saved - put your changes below here -"
 if { $prefsfile !="" } {
  set f [open $prefsfile]
  set prev_prefs [read $f]
@@ -460,12 +734,19 @@ if { $prefsfile !="" } {
  puts $f "set showtime_hours_per_day $showtime_hours_per_day"
  puts $f "set docdir \"$docdir\""
  puts $f "set rootdir \"$rootdir\""
+ puts $f "set showtime_spreadoverheads $showtime_spreadoverheads"
+ puts $f "set timebook_startlastweek $timebook_startlastweek"
  puts $f "set dateformat_view $dateformat_view"
+ puts $f "set dateformat_tcl $dateformat_tcl"
  puts $f "set num_today_actions $num_today_actions"
  puts $f "set history_win_depth $history_win_depth"
  puts $f "set current_win_depth $current_win_depth"
  puts $f "set id_prefix \"$id_prefix\""
- puts $f "$marker"
+ puts $f "set start_procs \{ $start_procs \}"
+ puts $f "set exit_procs $exit_procs"
+ puts $f "set projects_url \"$projects_url\""
+ puts $f "set activitiesfilename \"$activitiesfilename\""
+ puts $f "$marker" 
  puts $f "$prev_prefs"
 
  close $f
@@ -490,7 +771,10 @@ if { $prefsfile !="" } {
 
  close $f
 
+
+
 }
 
 }
 
+
