@@ -1,6 +1,8 @@
 #
 # This program gives a combined electronic diary and time clock.
-# Copyright John Lines (john@paladin.demon.co.uk) August 2001
+# This module deals with projects - which for taglog purposes are entities
+#  to which you book time.
+# Copyright John Lines (john@paladin.demon.co.uk) January 2003
 #
 # This program is released under the terms of the GNU Public Licence
 #
@@ -40,7 +42,7 @@ return 0
 }
 
 proc isactive { projname } {
-# return true if the give project is an overhead project
+# return true if the give project is an active project
 global projects
 
 foreach proj $projects {
@@ -123,6 +125,17 @@ if { [lindex $proj 0] == $projname } {
 return ""
 }
 
+proc proj_getDescription { proj } {
+global allproj
+
+}
+
+proc proj_setDescription { proj description } {
+global allproj
+
+
+}
+
 
 
 proc getProjTimes { files } {
@@ -188,6 +201,7 @@ return $results
 
 proc addProjectOK {} {
 global addproject_name addproject_breaks addproject_overheads addproject_bookas addproject_active projects addproject_startdate addproject_enddate
+global allproj
 
 set projects_entry [list $addproject_name 1 $addproject_bookas $addproject_overheads $addproject_breaks $addproject_startdate $addproject_enddate $addproject_active]
 lappend projects $projects_entry
@@ -261,6 +275,7 @@ proc doEditProjectsOK {} {
 global projects
 global epbreaks epoverheads epbookas epdelete epstart epend epactive
 
+
 set n 0
 set projindex 0
 foreach proj $projects {
@@ -479,7 +494,8 @@ set totallabelwidth [expr $projlabelwidth + 2 ]
 
 
  set i 1
-foreach project [array names projTimes] {
+# work through projTimes in sorted order
+foreach project [lsort [array names projTimes]] {
  frame .projwin.$i
  set projTxt $project
  if {$projTxt == "unknown"} {set projTxt [mc unknown]}
@@ -582,33 +598,13 @@ puts $f "End:"
 close $f
 }
 
-proc readprojects {} {
+proc allproj2projects {} {
+# transitional routine - set the projects global from the allproj global
+global projects allproj
 
-global projects projectsfilename allproj
-# Note that projects is not in tagged list format
-
-set allproj [tag readfile $projectsfilename]
-if { [ llength $allproj] == 0 } {
-  set hdr ""
-  set header [list Tag-accountproj-version 1.0]
-  lappend hdr $header
-  set endpair [list End ]
-  lappend hdr $endpair
-  lappend  allproj $hdr
-  }
-# puts "allproj is $allproj"
-
-# projects may have been read in from preferences
-# if they have then exit for now
 if {[info exists projects] } {
-# puts "projects is $projects"
- if { [llength $projects] != 0 } {
- writeprojects
- savePrefs
- return
- }
  unset projects
- }
+}
 
 # set projects to match allproj for transition
 foreach entry $allproj {
@@ -644,4 +640,142 @@ foreach entry $allproj {
 # If we have no projects yet we will create an empty list
 if { ![info exists projects] } { set projects {} }
 
+
 }
+
+proc readprojects {} {
+
+global projects projectsfilename allproj
+# Note that projects is not in tagged list format
+
+set allproj [tag readfile $projectsfilename]
+if { [ llength $allproj] == 0 } {
+  set hdr ""
+  set header [list Tag-accountproj-version 1.0]
+  lappend hdr $header
+  set endpair [list End ]
+  lappend hdr $endpair
+  lappend  allproj $hdr
+  }
+# puts "allproj is $allproj"
+
+# projects may have been read in from preferences
+# if they have then exit for now
+if {[info exists projects] } {
+# puts "projects is $projects"
+ if { [llength $projects] != 0 } {
+ writeprojects
+ savePrefs
+ return
+ }
+ unset projects
+ }
+
+# set projects to match allproj for transition
+allproj2projects
+
+}
+
+proc can_get_httprojects {} {
+global projects_url
+# return true if we can get projects information by http
+
+if { [info tclversion] >= 8.0 } {
+ package require http
+
+ if { $projects_url == "" } { return 0 }
+
+ return 1
+ }
+
+return 0
+}
+
+proc update_projects_ok {} {
+global allproj update_projects_allproj
+
+set allproj $update_projects_allproj
+allproj2projects
+destroy .update_info
+}
+
+proc doUpdateProjects {} {
+global projects_url allproj update_projects_allproj
+
+toplevel .update_info
+wm title .update_info "Projects HTTP update report"
+text .update_info.text -width 60 -height 20
+
+frame .update_info.bot
+button .update_info.bot.ok -text "OK" -command update_projects_ok
+button .update_info.bot.cancel -text "Cancel" -command "destroy .update_info"
+button .update_info.bot.help -text "Help" -command "taghelp project_update"
+pack .update_info.text
+pack .update_info.bot.ok .update_info.bot.cancel .update_info.bot.help -side left -in .update_info.bot
+pack .update_info.bot
+
+set p [::http::geturl $projects_url]
+
+set body [::http::data $p]
+
+# 
+set newproj [tag readbuf body]
+
+#.update_info.text insert end $newproj
+
+set today [clock format [clock seconds] -format "%Y-%m-%d"]
+
+# Go through allproj and compare to newproj to find projects which
+# have been closed - write the info to a global array called update_projects_allproj
+
+foreach proj $allproj {
+ set thisproj_name [logEdit_tagVal $proj Name]
+ set found 0
+ foreach newp $newproj {
+   if { [logEdit_tagVal $newp Name] == $thisproj_name } {
+    # This project still exists - just copy it across
+    lappend update_projects_allproj $proj
+    set found 1
+    break
+    }
+  }
+ if { !$found } {
+  # This project is now closed - set the enddate to today
+  # unless the project was already closed
+  if { ! [ projclosed $thisproj_name ] } {
+  tag setorreplace proj EndDate $today 
+  .update_info.text insert end "Closed $thisproj_name\n"
+  lappend update_projects_allproj $proj
+  }
+ }
+
+}
+
+# Go through newproj and find all the projects which are not already in update_projects_allproj
+# and add them
+
+foreach newp $newproj {
+ set thisproj_name [logEdit_tagVal $newp Name]
+ set found 0
+   foreach proj $update_projects_allproj {
+     if { [logEdit_tagVal $proj Name] == $thisproj_name } {
+    # This project has already been found
+    set found 1
+    break
+    }
+  }
+  if { !$found } {
+  # We have a new project - append its details to update_projects_allpoj
+     .update_info.text insert end "Added $thisproj_name\n"
+    lappend update_projects_allproj $newp
+  }
+}
+
+
+
+tkwait window .update_info
+unset update_projects_allproj
+
+}
+
+
