@@ -8,14 +8,15 @@
 package provide taglog_report 0.1
 
 proc doTotalTimeForProjectOK {} {
-global totalprojtimessel_project totalprojtimessel_startdate totalprojtimessel_enddate showtime_format
+    #changed by gbarisan@ieee.org to show activities breakdown
+global totalprojtimessel_project totalprojtimessel_startdate totalprojtimessel_enddate showtime_format GL_tableFont
 
 toplevel .totalprojtimesres
 wm title .totalprojtimesres "[mc {Total Times for}] $totalprojtimessel_project"
 
 frame .totalprojtimesres.main
-text .totalprojtimesres.main.body -height 5
-pack .totalprojtimesres.main.body
+#text .totalprojtimesres.main.body -height 5
+#pack .totalprojtimesres.main.body
 
 set projtotal "00:00"
 set firstdate ""
@@ -68,19 +69,90 @@ foreach filename $fileslist {
 
 }
 
-.totalprojtimesres.main.body insert end "[mc {Total time for}] '$totalprojtimessel_project' [mc is] "
+
+########### Calculating the activities breakdown
+#added by gbarisan@ieee.org on 2003-11-07
+#
+
+set activities {}
+set acttotal "00:00"
+set actProj ""
+
+foreach filename $fileslist {
+    set logs [tag readfile $filename]
+    
+    foreach entry $logs {
+        set starttime 0
+        set endtime 0
+        set activity unknown
+        foreach item $entry {
+            
+            set tagname [lindex $item 0]
+            set tagvalue [lindex $item 1]
+            if { $tagname == "End" } then {
+                if { $actProj == $totalprojtimessel_project} {
+                    set duration [timediff $starttime $endtime]
+                    # more to do here
+                    inctime acttotal $duration
+                    if { [lsearch -exact $activities $activity] == -1 } {
+                        lappend activities $activity
+                        set acttime($activity) "00:00"
+                    }
+                    inctime acttime($activity) $duration}
+            } elseif { $tagname == "StartTime" } {
+                set starttime $tagvalue
+            } elseif { $tagname == "EndTime" } {
+                set endtime $tagvalue
+            } elseif { $tagname == "Activity" } {
+                set activity $tagvalue
+            } elseif { $tagname == "Project"} {
+                set actProj $tagvalue
+            } else  {
+            }
+        }
+    }
+    
+}
+
+set resultheight [expr {[array size acttime] + 10} ]
+
+
+if { $resultheight > 20 } {
+    text .totalprojtimesres.main.body -rel sunk -yscrollcommand ".totalprojtimesres.main.sb set" -height $resultheight \
+            -font $GL_tableFont -tabs { 5c left 2c 2c left }
+    pack .totalprojtimesres.main.body -in .totalprojtimesres.main -side left -fill y
+    scrollbar .totalprojtimesres.main.sb -rel sunk -command ".totalprojtimesres.main.body yview"
+    pack .totalprojtimesres.main.sb -in .totalprojtimesres.main -side left -fill y
+} else {
+    text .totalprojtimesres.main.body -rel sunk -height $resultheight \
+            -font $GL_tableFont -tabs { 5c left 2c 2c left }
+    pack .totalprojtimesres.main.body -in .totalprojtimesres.main -side left -fill y
+}
+pack .totalprojtimesres.main
+
+.totalprojtimesres.main.body insert end "[mc {Total time for Project}] '$totalprojtimessel_project' [mc is] "
 set saved_format $showtime_format
 set showtime_format 2
 DisplayTime .totalprojtimesres.main.body projtotal
 .totalprojtimesres.main.body insert end " [mc {decimal days}] = "
 set showtime_format 0
 DisplayTime .totalprojtimesres.main.body projtotal
-.totalprojtimesres.main.body insert end " hh:mm:ss\n"
+.totalprojtimesres.main.body insert end " hh:mm\n"
 .totalprojtimesres.main.body insert end "[mc Examined] $numfileschecked [mc {files and found entries for}] '$totalprojtimessel_project' in $numprojdays [mc {of them}]\n"
 
 set firstdate [logfilename2date $firstdate]
 set lastdate [logfilename2date $lastdate]
-.totalprojtimesres.main.body insert end "[mc {First date was}] $firstdate - [mc {last date was}] $lastdate\n"
+.totalprojtimesres.main.body insert end "[mc {First date was}] $firstdate - [mc {last date was}] $lastdate\n\n"
+
+.totalprojtimesres.main.body insert end "[mc Activity]\t[mc {Total time}]\n\n"
+foreach act [array names acttime] {
+    .totalprojtimesres.main.body insert end "$act\t$acttime($act)\n"
+}
+.totalprojtimesres.main.body insert end "\t--------\n"
+.totalprojtimesres.main.body insert end "\n[mc Total]\t$projtotal\n"
+
+
+############ end of gbarisan changes
 
 pack .totalprojtimesres.main
 frame .totalprojtimesres.bot
@@ -149,24 +221,27 @@ tkwait window .totalprojtimes
 
 }
 
-
-
 proc DisplayTime { window timevar args } {
 global showtime_format showtime_hours_per_day
-global tcl_platform
-set mm 0
-set hh 0
+ global tcl_platform
+ set mm 0
+ set hh 0
+ set ss 0
 
-upvar $timevar time
-if { ! [ info exist time ] } {
- $window insert end "     "
- return
- } 
- scan $time "%d:%d" hh mm
+ upvar $timevar time
+ if { ! [ info exist time ] } {
+  $window insert end "     "
+  return
+  }
+
+ scan $time "%d:%d:%d" hh mm ss
 if { $showtime_format==0 } {
+   if { $ss > 30 } { incr mm }
    set showtime [format "%02d:%02d" $hh $mm]
   } elseif { $showtime_format == 1 } {
- set mins [expr { $mm*100/60 } ]
+# set mins [expr { $mm*100/60 } ]
+ set mins [expr {round( $mm*100.0/60.0) } ]
+   if { $ss > 30 } { incr mm }
  set showtime [format "%02d.%02d" $hh $mins]
  } elseif { $showtime_format == 2 } {
   # show time in decimal days
@@ -183,6 +258,8 @@ if {$args == "bold"} {
     $window tag configure boldtag -font {-weight bold}
  }
  $window insert end "$showtime" boldtag
+ } elseif { $args == "bodydata" } {
+   $window insert end "$showtime" bodydata
  } else {
 $window insert end "$showtime"
 }
@@ -274,6 +351,88 @@ tkwait window $w
 
 }
 
+proc saveTimeBookings {} {
+global html_public_dir default_save_timebookings_file timebookings_file_format
+
+set saveas_dir $html_public_dir
+set saveas_file ""
+
+if {[info exists default_save_timebookings_file ]} {
+   set saveas_dir [file dirname $default_save_timebookings_file]
+   set saveas_file [file tail $default_save_timebookings_file]  
+}
+
+
+set tbfile [tk_getSaveFile -title [mc "Save Time Bookings File"] -defaultextension ".csv" -initialdir $saveas_dir -initialfile $saveas_file -filetypes {{{CSV files} {.csv}} { {All files} {*}}}]
+
+if { $tbfile == "" } { return }
+
+set f [ open $tbfile "w"]
+
+if { [info exists timebookings_file_format ] } {
+	fconfigure $f -translation $timebookings_file_format
+}
+
+# Get the contents of the .timebook.main frame
+
+
+# set timebook_body [string trim [.timebook.main.body get bodydata.first bodydata.last]]
+
+set i 1.0
+set done 0
+set timebook_body ""
+
+while { ! $done } {
+ set r [ .timebook.main.body tag nextrange bodydata $i]
+ if { $r == "" } {
+    set done 1
+  } else {
+  set timebook_this [ .timebook.main.body get [lindex $r 0] [lindex $r 1]]
+  set timebook_body "$timebook_body$timebook_this"
+  set i [lindex $r 1]
+ }
+}
+
+# Change tabs to commas
+regsub -all \t $timebook_body , timebook_body2
+
+# Change ,, to , 0.0 ,
+regsub -all ",," $timebook_body2 ,0.0, timebook_body
+
+# Repeat to catch the ones we miss with only one pass
+regsub -all ",," $timebook_body ,0.0, timebook_body2
+
+# Now deal with a trailing comma
+
+regsub -all ,\n $timebook_body2 ,0.0\n timebook_body
+
+# Trim white space
+
+set timebook_body [string trim $timebook_body]
+set timebook_body [string trimright $timebook_body \n]
+
+puts $f $timebook_body
+
+
+close $f
+
+}
+
+proc firstDayOfWeek { weekno year } {
+# returns the day number of the first day of week weekno for a particular year
+
+# what day of the week is the first
+set firstday [clock format [clock scan "1 jan $year"] -format "%w"]
+# puts "first day is $firstday"
+if { $firstday < 4 } { incr firstday 7 }
+#set offset [expr { ( 8- $firstday ) %7 } ]
+set offset [expr { 1- $firstday } ]
+# puts "offset is $offset"
+
+return [expr { $weekno*7 + $offset }]
+}
+
+
 proc showTimeBookings {} {
 global timebook_year timebook_weekno rootdir showtime_format showtime_spreadoverheads showtime_bookbycode timebook_numweeks
 global GL_tableFont
@@ -281,8 +440,6 @@ global GL_tableFont
 toplevel .timebook
 wm title .timebook [mc "Time Bookings"]
 
-set booked_projects {}
-
 # We wont display errors unless we have to
 set display_errors 0
 frame .timebook.errors
@@ -308,7 +465,8 @@ pack .timebook.main -fill both -expand 1
 frame .timebook.bot
 button .timebook.bot.ok -text OK -command { doCancel .timebook }
 button .timebook.bot.mail -text "Mail..." -command { mailTimeBookings } 
-pack .timebook.bot.ok .timebook.bot.mail -side left -in .timebook.bot
+button .timebook.bot.saveas -text [mc "Save As..."] -command { saveTimeBookings }
+pack .timebook.bot.ok .timebook.bot.mail .timebook.bot.saveas -side left -in .timebook.bot
 pack .timebook.bot
 
 for { set weekinc 0 } { $weekinc < $timebook_numweeks } { incr weekinc } {
@@ -316,18 +474,20 @@ for { set weekinc 0 } { $weekinc < $timebook_numweeks } { incr weekinc } {
 # work out which files we need - how do we convert a week number into
 # a set of days ?
 
-# what day of the week is the first
-set firstday [clock format [clock scan "1 jan $timebook_year"] -format "%w"]
-# puts "first day is $firstday"
-set offset [expr { ( 8- $firstday ) %7 } ]
-# puts "offset is $offset"
-
 set thisweek [expr $timebook_weekno + $weekinc]
-set startday [expr { $thisweek*7 + $offset }]
+set startday [firstDayOfWeek $thisweek $timebook_year]
 
 
 .timebook.main.body insert end "\t\t[mc {Time Bookings for week}] $thisweek [mc of] $timebook_year\n\n"
 
+# initialize totals variables used for this loop
+
+set booked_projects {}
+set total_overheads "00:00:00"
+set nonbreakstotal "00:00:00"
+set breakstotal "00:00:00"
+
+
 # Clear all the arrays used for totals
 if [ info exists projtotals ] {
 unset projtotals
@@ -396,7 +556,6 @@ unset projtimes${day}
  
   } else { 
   # add the project to booked_projects if we have not seen it before
-#  if { [lsearch -exact $booked_projects $thisproject ] == -1 } 
   if { [lsearch -exact $booked_projects $displayname ] == -1 } {
 	lappend booked_projects $displayname
 	set projtotals($displayname) "00:00"
@@ -425,11 +584,13 @@ unset projtimes${day}
 
  } else {
    # want to warn if we cant open the file (unless it is Sat or Sun)
+ if {[ clock format [clock scan "1 jan $timebook_year $day days"] -format "%u"] <6 } {
  .timebook.errors.body insert end "[mc {Warning - cant open}] $filename\n"
  if { ! $display_errors } {
 	pack .timebook.errors -side top
 	set display_errors 1
 	}
+  }
  }
 
 }
@@ -465,12 +626,17 @@ for { set day $startday } {$day < [expr {$startday+7} ]} { incr day } {
 .timebook.main.body insert end "   \t"
 }
 .timebook.main.body insert end "\n"
-.timebook.main.body insert end "[mc Day]\t \t    "
+.timebook.main.body insert end "[mc Day]\t "
+.timebook.main.body insert end "\t" bodydata
+.timebook.main.body insert end "    "
 for { set day $startday } {$day < [expr {$startday+7} ]} { incr day } {
-.timebook.main.body insert end [clock format [clock scan "1 jan $timebook_year $day days"] -format "%d/%m"]
-.timebook.main.body insert end " \t"
+.timebook.main.body insert end [clock format [clock scan "1 jan $timebook_year $day days"] -format "%d/%m"] bodydata
+if { $day < [expr {$startday+6}]} {
+.timebook.main.body insert end " "
+.timebook.main.body insert end "\t" bodydata
 }
-.timebook.main.body insert end "\n\n"
+}
+.timebook.main.body insert end "\n\n" bodydata
 
 # work through the booked projects
 foreach thisproject $booked_projects {
@@ -478,16 +644,16 @@ foreach thisproject $booked_projects {
 
 # write out the projects as constant width
 set displayproj [string range $thisproject 0 18]
-.timebook.main.body insert end "$displayproj\t"
+.timebook.main.body insert end "$displayproj\t" bodydata
 
 for { set day $startday } {$day < [expr {$startday+7}]} { incr day } {
 if { $showtime_spreadoverheads && [ info exists dayoverheads($day)]  } {
-# redistribute the spare minutes
- set minstospread [timediff "00:00"  $dayoverheads($day)]
- set minsthisproj [ expr { round( $minstospread * $projfraction($thisproject))}]
+# redistribute the spare minutes (or seconds now that we work in them)
+ set secstospread [timediff "00:00"  $dayoverheads($day)]
+ set secsthisproj [ expr { round( $secstospread * $projfraction($thisproject))}]
 # puts "We have  $dayoverheads($day) = $minstospread minutes to spread _ $minsthisproj"
- inctime projtimes${day}($thisproject) $minsthisproj
- inctime projtotals($thisproject) $minsthisproj
+ inctime projtimes${day}($thisproject) $secsthisproj
+ inctime projtotals($thisproject) $secsthisproj
 
 }
 }
@@ -497,16 +663,17 @@ DisplayTime .timebook.main.body projtotals($thisproject) bold
 .timebook.main.body insert end "\t"
 
 for { set day $startday } {$day < [expr {$startday+7}]} { incr day } {
-DisplayTime .timebook.main.body projtimes${day}($thisproject)
+DisplayTime .timebook.main.body projtimes${day}($thisproject) bodydata
 if { $day < [expr {$startday+6}]} {
-.timebook.main.body insert end " \t"
+.timebook.main.body insert end " " 
+.timebook.main.body insert end "\t" bodydata
 }
 }
 
-.timebook.main.body insert end "\n"
+.timebook.main.body insert end "\n" bodydata
 }
 
-.timebook.main.body insert end "\n"
+.timebook.main.body insert end "\n" bodydata
 # write the totals for all days
 .timebook.main.body insert end "\t"
 DisplayTime .timebook.main.body nonbreakstotal bold
@@ -521,16 +688,6 @@ DisplayTime .timebook.main.body daytotal($day) bold
 DisplayTime .timebook.main.body breakstotal bold
 .timebook.main.body insert end "\n"
 
-if [info exists nonbreakstotal] {
-unset nonbreakstotal
-}
-if [info exists breakstotal] {
-unset breakstotal
-}
-if [info exists total_overheads] {
-unset total_overheads
-}
-set booked_projects {}
 }
 
 
@@ -541,6 +698,7 @@ tkwait window .timebook
 
 proc doWeeklyTimeBookingsByProject {} {
 global year timebook_year timebook_weekno showtime_format showtime_spreadoverheads showtime_bookbycode timebook_numweeks
+global timebook_startlastweek
 toplevel .timebooksel
 wm title .timebooksel [mc "Select Time Period"]
 
@@ -590,7 +748,8 @@ bind .timebooksel.m.numweeks.e <KeyRelease> "setWeekRange .timebooksel.wrange"
 set timebook_weekno [ string trimleft [ clock format [clock seconds] -format "%W"] 0]
 # This will give us null string for week 0 - pick that up as well
 if {$timebook_weekno == ""} {set timebook_weekno 0}
-incr timebook_weekno -1
+# incr timebook_weekno -1
+if { ! $timebook_startlastweek } { incr timebook_weekno }
 frame .timebooksel.m.week
 menubutton .timebooksel.m.week.l -text [mc "starting at number"] -menu .timebooksel.m.week.l.m
 menu .timebooksel.m.week.l.m
@@ -698,6 +857,8 @@ pack .tba.bot
 tkwait window .tba
 }
 
+
+
 proc doTimeByActivity {} {
 global timebyact_start timebyact_end
 
@@ -751,13 +912,22 @@ pack .projrepinfo.selproj.p
 pack .projrepinfo.selproj
 
 frame .projrepinfo.start
-menubutton .projrepinfo.start.l -text [mc "Start Date"]
+menubutton .projrepinfo.start.l -text [mc "Start Date"] -menu .projrepinfo.start.l.m
+menu .projrepinfo.start.l.m
+ set md [clock format [clock scan "last month"] -format "%Y-%m-01"]
+.projrepinfo.start.l.m add command -label "$md [mc {Start of last month}]" -command "set projrepinfosel_start $md"
+
+
 calUtil_win .projrepinfo.start.e "" projrepinfosel_start
 pack .projrepinfo.start.l .projrepinfo.start.e -in .projrepinfo.start -side left
 pack .projrepinfo.start
 
 frame .projrepinfo.end
-menubutton .projrepinfo.end.l -text [mc "End Date"]
+menubutton .projrepinfo.end.l -text [mc "End Date"] -menu .projrepinfo.end.l.m
+menu .projrepinfo.end.l.m
+ set md [clock format [clock seconds] -format "%Y-%m-01"]
+.projrepinfo.end.l.m add command -label "$md [mc {Start of this month}]" -command "set projrepinfosel_end $md"
+
 calUtil_win .projrepinfo.end.e "" projrepinfosel_end
 pack .projrepinfo.end.l .projrepinfo.end.e -in .projrepinfo.end -side left
 pack .projrepinfo.end
@@ -773,46 +943,76 @@ tkwait window .projrepinfo
 
 }
 
-proc doProjectReportOK { proj start end } {
+proc doProjectReportOK { proj start end { mode screen } } {
 global allact allactstate
 global scrollside
 global GL_tableFont
+global html_public_dir
 
+
+if { $mode == "screen" } {
 toplevel .projrep
 wm title .projrep "[mc {Project Progress Report for}] $proj"
+} else {
+ set fn [tk_getSaveFile -defaultextension ".html" -initialdir $html_public_dir]
+ if { $fn != "" } {
+  set f [open $fn w]
+  puts $f "<head>"
+  puts $f "<title>[mc {Project Progress Report for}] $proj</title>"
+ }
+
+}
 
 getallact
 
+
+if { $mode == "screen" } {
 frame .projrep.main
 text .projrep.main.body -rel sunk -wrap word -yscrollcommand ".projrep.main.sb set" \
  -font $GL_tableFont -tabs { 12c left 3c 3c }
 scrollbar .projrep.main.sb -rel sunk -command ".projrep.main.body yview"
-pack .projrep.main.body -side $scrollside -in .projrep.main
+pack .projrep.main.body -side $scrollside -in .projrep.main -fill both -expand 1
 pack .projrep.main.sb -side $scrollside -fill y -in .projrep.main
-pack .projrep.main
+pack .projrep.main -fill both -expand 1
 
 
 
 frame .projrep.bot
 button .projrep.bot.ok -text OK -command { doCancel .projrep }
+button .projrep.bot.save -text "[mc {SaveAs Html}]" -command "doProjectReportOK \"$proj\" \"$start\" \"$end\" html"
 
 pack .projrep.bot.ok -side left
+pack .projrep.bot.save -side left
 pack .projrep.bot
 
-
 # Now fill the window
 
-.projrep.main.body insert end "Project Progress Report\n"
-.projrep.main.body insert end "Project\t$proj\n"
-.projrep.main.body insert end "Progress from $start to $end\n\n"
+.projrep.main.body insert end [mc "Project Progress Report"]\n
+.projrep.main.body insert end [mc "Project"]\t$proj\n
+.projrep.main.body insert end "[mc {Progress from}] $start[mc { to }]$end\n\n"
 
-.projrep.main.body insert end "Achievements\n"
-.projrep.main.body insert end "Tasks completed since last report\n"
-.projrep.main.body insert end "Title\tExpected\tActual\t\n\tDate\tDate\n"
+.projrep.main.body insert end [mc Achievements]\n
+.projrep.main.body insert end [mc "Tasks completed since last report"]\n
+.projrep.main.body insert end "[mc Title]\t[mc Expected]\t[mc Actual]\t\n\t[mc Date]\t[mc Date]\n"
+} else {
+ puts $f "</head><body><h1>[mc "Project Progress Report"]</h1>"
+ puts $f "<h2>[mc "Project"]\t$proj</h2>"
+ puts $f "[mc {Progress from}] $start[mc { to }]$end <p>"
+ puts $f "<h3>[mc Achievements]</h3>"
+ puts $f "[mc "Tasks completed since last report"]"
+ puts $f "<table><tr><th>[mc Title]</th><th>[mc Expected] [mc Date]</th><th>[mc Actual] [mc Date]</th></tr>"
+ }
 
+
+
+if { $proj != "" } {
  set test [list Project == $proj]
-lappend tests $test
-set actions [ tag extract $allact $tests ]
+ lappend tests $test
+ set actions [ tag extract $allact $tests ]
+ } else {
+ set actions $allact
+ }
+
 
 # looking for tasks completed since the last report
 
@@ -835,15 +1035,25 @@ foreach item $entry {
  } 
 
 }
- 
+
+ if { $mode == "screen" } {
 .projrep.main.body insert end "$title\t$expected_completed_date\t$completed_date\n"
+ } else {
+ puts $f "<tr><td>$title</td><td>$expected_completed_date</td><td>$completed_date</td></tr>"
+ }
 }
 
 }
 
 # looking for tasks started since the last report
-.projrep.main.body insert end "\n\nTasks started since last report\n"
-.projrep.main.body insert end "Title\tExpected\tActual\t\n\tDate\tDate\n"
+if { $mode =="screen" } {
+.projrep.main.body insert end "\n\n[mc {Tasks started since last report}]\n"
+.projrep.main.body insert end "[mc Title]\t[mc Expected]\t[mc Actual]\t\n\t[mc Date]\t[mc Date]\n"
+ } else {
+ puts $f "</table><h3>[mc {Tasks started since last report}]</h3>"
+ puts $f "<table>"
+ puts $f "<tr><th>[mc Title]</th><th>[mc Expected] [mc Date]</th><th>[mc Actual] [mc Date]</th></tr>"
+}
 
 foreach entry $actions {
 
@@ -864,7 +1074,11 @@ foreach item $entry {
  } 
 }
 
+if { $mode == "screen"} {
 .projrep.main.body insert end "$title\t$expected_started_date\t$started_date\n"
+ } else {
+ puts $f "<tr><td>$title</td><td>$expected_started_date</td><td>$started_date</td></tr>"
+}
 
 }
 }
@@ -874,8 +1088,16 @@ foreach item $entry {
 # also tasks which are still pending, even though they have reached their
 #  expected start date must have slipped.
 # Not quite sure how to do this
-.projrep.main.body insert end "\n\nTasks slipped since last report\n"
-.projrep.main.body insert end "Title\tExpected\tActual\t\n\tDate\tDate\n"
+
+if { $mode == "screen" } {
+.projrep.main.body insert end "\n\n[mc {Tasks slipped since last report}]\n"
+.projrep.main.body insert end "[mc Title]\t[mc Expected]\t[mc Actual]\t\n\t[mc Date]\t[mc Date]\n"
+} else {
+ puts $f "</table>"
+ puts $f "<h3>[mc {Tasks slipped since last report}]</h3>"
+ puts $f "<table>"
+ puts $f "<tr><th>[mc Title]</th><th>[mc Expected] [mc Date]</th><th>[mc Actual] [mc Date]</th></tr>"
+}
 
 foreach entry $actions {
 
@@ -896,14 +1118,26 @@ foreach item $entry {
  } 
 }
 
+if { $mode == "screen" } {
 .projrep.main.body insert end "$title\t$expected_started_date\t$started_date\n"
+ } else {
+ puts $f "<tr><td>$title</td><td>$expected_started_date</td><td>$started_date</td></tr>"
+ }
 
 }
 }
 
 # looking for active tasks
-.projrep.main.body insert end "\n\nActive tasks\n"
-.projrep.main.body insert end "Title\tScheduled\tForecast\t\n\tCompletion\tCompletion\n"
+if { $mode == "screen" } {
+.projrep.main.body insert end "\n\n[mc {Active tasks}]\n"
+.projrep.main.body insert end "[mc Title]\t[mc Scheduled]\t[mc Forecast]\t\n\t[mc Completion]\t[mc Completion]\n"
+} else {
+ puts $f "</table>"
+ puts $f "<h3>[mc {Active tasks}]</h3>"
+ puts $f "<table>"
+ puts $f "<tr><th>[mc Title]</th><th>[mc Scheduled] [mc Completion]</th><th>[mc Forecast] [mc Completion]</th></tr>"
+
+}
 
 foreach entry $actions {
 
@@ -924,27 +1158,37 @@ foreach item $entry {
  } 
 }
 
+if { $mode == "screen" } {
 .projrep.main.body insert end "$title\t$expected_completed_date\t$started_date\n"
+ } else {
+ puts $f "<tr><td>$title</td><td>$expected_completed_date</td><td>$started_date</td></tr>"
+ }
 
 }
 }
 
 
+if { $mode == "screen" } {
 tkwait window .projrep
+ } else {
+
+ puts $f "</table>"
+ puts $f "</body>"
+ close $f
+
+}
+ 
 }
 # fills the range of days into the widget $wRange
 proc setWeekRange {wRange} {
    global timebook_year timebook_numweeks timebook_weekno
    global dateformat_view
 
+
    if {[winfo exists $wRange]} {
       if {![catch {
 	 # check year, execute illegal command if year is out of range
 	 if {$timebook_year < 1970 || $timebook_year > 2100} {$xxxx}
-	 # what day of the week is the first
-	 set firstday [clock format [clock scan "1 jan $timebook_year"] \
-	 						-format "%w"]
-	 set offset [expr { ( 8- $firstday ) %7 } ]
 	 if {$dateformat_view == "DD/MM/YYYY" } {
 	    set dForm "%d/%m/%Y"
 	    set dLen 30
@@ -955,7 +1199,7 @@ proc setWeekRange {wRange} {
 	    set dForm "%Y-%m-%d"
 	    set dLen 32
 	 }
-	 set startday [expr { $timebook_weekno*7 + $offset }]
+	 set startday [firstDayOfWeek $timebook_weekno $timebook_year]
 	 set startStr [ clock format \
 	  [clock scan "1 jan $timebook_year $startday days"] -format $dForm]
 	 set endday [expr {$startday + $timebook_numweeks * 7 - 1}]
@@ -972,3 +1216,93 @@ proc setWeekRange {wRange} {
    }
    return True
 }
+
+proc doInterruptionsReport {} {
+global intrepask_start intrepask_end
+
+toplevel .intrepask
+wm title .intrepask [mc "Interruptions Report setup"]
+
+frame .intrepask.start
+menubutton .intrepask.start.b -text [mc "Start Date"] -menu .intrepask.start.b.m
+menu .intrepask.start.b.m
+calUtil_win .intrepask.start.e "" intrepask_start
+pack .intrepask.start.b .intrepask.start.e -in .intrepask.start -side left
+pack .intrepask.start
+
+frame .intrepask.end
+menubutton .intrepask.end.b -text [mc "End Date"] -menu .intrepask.end.b.m
+menu .intrepask.end.b.m
+calUtil_win .intrepask.end.e "" intrepask_end
+pack .intrepask.end.b .intrepask.end.e -in .intrepask.end -side left
+pack .intrepask.end
+
+frame .intrepask.bot
+button .intrepask.bot.ok -text OK -command doInterruptionsReportOK
+button .intrepask.bot.cancel -text [mc Cancel] -command { doCancel .intrepask }
+pack .intrepask.bot.ok .intrepask.bot.cancel -in .intrepask.bot -side left
+pack .intrepask.bot
+
+tkwait window .intrepask
+
+
+}
+
+proc doInterruptionsReportOK {} {
+global intrepask_start intrepask_end
+global GL_tableFont
+
+toplevel .intrep
+wm title .intrep [mc "Interruptions Report"]
+
+set totalInterrupts 0
+set numdays 0
+set peakipd 0
+set fileslist [dateRangeToLogfileList $intrepask_start $intrepask_end]
+foreach filename $fileslist {
+ set dayInterrupts 0
+ incr numdays
+ set logs [tag readfile $filename]
+
+ foreach entry $logs {
+    foreach item $entry {
+     set tagname [lindex $item 0]
+     set tagvalue [lindex $item 1]
+      if { $tagname == "Stack-info" } {
+       if { [string range $tagvalue 0 0] == "!" } {
+         incr dayInterrupts
+         incr totalInterrupts
+         }
+       }
+   }
+
+}
+if { $dayInterrupts > $peakipd } {
+  set peakipd $dayInterrupts
+  }
+
+}
+
+frame .intrep.results
+text .intrep.results.body -rel sunk -height 10 -font $GL_tableFont -tabs { 5c left 2c 2c left }
+
+pack .intrep.results.body -in .intrep.results -side right -fill y
+pack .intrep.results
+
+
+.intrep.results.body insert end "[mc {There were a total of}] $totalInterrupts [mc {interruptions in}] $numdays [mc days.]\n"
+
+set avg [expr $totalInterrupts/$numdays]
+
+.intrep.results.body insert end "[mc {The average number of interruptions in a day was}] $avg\n"
+.intrep.results.body insert end "[mc {The peak number of interruptions per day was}] $peakipd\n"
+
+frame .intrep.bot
+button .intrep.bot.ok -text OK -command {doCancel .intrep }
+pack .intrep.bot.ok -in .intrep.bot
+pack .intrep.bot
+
+tkwait window .intrep
+
+}
+
